atomic_desing_system_package library
Classes
- AtomAvatar
- AtomButton
- AtomCard
- AtomCheckbox
- AtomChip
- AtomFAB
- AtomIcon
- AtomIconButton
- AtomImg
- AtomInput
- AtomLabel
-
AtomRadio<
T> - AtomSwitch
- AtomText
- AtomTextButton
- MoleculeActionButtons
- MoleculeAvatarWithName
- MoleculeCard
- MoleculeConfirmModal
- MoleculeDateField
-
MoleculeDropdownField<
T> - MoleculeEmailField
- MoleculeIconCard
- Card compacto con icono y texto, usando solo átomos
- MoleculeInputWithHelperText
- MoleculeLinkForgotPassword
- MoleculePasswordField
- MoleculePhoneField
- MoleculeSearchBar
- MoleculeSimpleModal
- OrganismCarousel
- OrganismHeaderIcon
- OrganismHeaderSearchBox
- OrganismHeaderWithoutSearch
- OrganismListCard
- OrganismListIconCard
- OrganismLoginForm
- PageContact
- PageDashboard
- PageDetail
- PageListCartsTemplate
- PageLogin
- TemplateBasePage
- Template base reutilizable para cualquier página con header, body y footer. Permite pasar widgets personalizados o construir una lista de cards si se pasan los parámetros de lista.
- TemplateContactPage
- TemplateDashboardPage
- TemplateDetailPage
- TemplateListCarts
- TemplateLoginPage