TemplateBasePage class

Template base reutilizable para cualquier página con header, body y footer. Permite pasar widgets personalizados o construir una lista de cards si se pasan los parámetros de lista.

Inheritance

Constructors

TemplateBasePage({Key? key, required Widget header, required Widget footer, Color? headerBackgroundColor, Color? footerBackgroundColor, Widget? body, bool isList = false, List<String>? imageUrls, List<String>? descriptions, List<VoidCallback?>? onSeeMoreCallbacks, Widget? bodyWhenEmpty, String? descriptiveTitle, String? descriptiveSubtitle, String? descriptiveImageUrl, String? descriptiveTextFieldHint, String? descriptiveButtonText, bool descriptiveButtonDependsOnText = false, void descriptiveOnButtonPressed(String text)?})
Si se pasan los 3 parámetros de lista, el body se construye como lista de cards. Si las listas están vacías, se muestra el body descriptivo. Si no, se usa el widget body proporcionado.
const

Properties

body Widget?
final
bodyWhenEmpty Widget?
final
descriptions List<String>?
final
descriptiveButtonDependsOnText bool
final
descriptiveButtonText String?
final
descriptiveImageUrl String?
final
descriptiveOnButtonPressed → void Function(String text)?
final
descriptiveSubtitle String?
final
descriptiveTextFieldHint String?
final
descriptiveTitle String?
final
final
footerBackgroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
final
headerBackgroundColor Color?
final
imageUrls List<String>?
final
isList bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSeeMoreCallbacks List<VoidCallback?>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TemplateBasePage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited